# AnalysisResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**analysis_id** | **str** | An id of submitted analysis for checking its status and its results.  |
**parameters** | **object** | Parameters echoed back to user (with default parameters if omitted).  |
**cached** | **bool** | If set to true the given analysis was picked from cache.  |

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

